
/**
 * \mainpage ELL - Energy Landscape Library
 *
 * This document provides reference information about the
 * <A HREF="http://www.bioinf.uni-freiburg.de/SW/ELL/">Energy Landscape Library</A>
 * version 0.1.
 *
 * \section SecGoals The goal
 *
 * This C++ programming library provides a platform for generic algorithms to
 * study kinetics and structure of energy landscapes with descrete states. This
 * algorithms need an abstract representation of this states to be applied to
 * a multitude of modells and the corresponding energy or fitness landscapes.
 *
 * \section SecFeatures Features
 *
 * - an RNA representation interfacing the <A HREF="http://www.tbi.univie.ac.at/~ivo/RNA/">
 *   Vienna RNA package</A> for energy calculation
 * - generic formulation for lattice modells (e.g. square, cubic, ...) with the
 *   corresponding automorphisms (e.g. rotation etc.)
 * - lattice protein representations for this lattice modells with arbitrary
 *   contact energy functions
 * - exact pivot move definition and implementation for lattice proteins
 * - abstract state representations for RNA and lattice proteins, that generate
 *   their landscape neighborhood for their modells
 *
 * \section SecDependencies Dependencies
 *
 * The ELL depends on the following libraries:
 *
 * - the <A HREF="http://www.bioinf.uni-freiburg.de/SW/BIU/">Bioinformatic Utility</A>
 *   library (BIU)
 * - the <A HREF="http://www.tbi.univie.ac.at/~ivo/RNA/">Vienna RNA package</A>
 *
 * Additionally, the documentation also features the following parts:
 *  - \ref PageInstallation
 *
 * The following lists and indices are available
 *  - <a class="el" href="annotated.html">List of all classes including brief documentation</a>
 *  - <a class="el" href="namespaces.html">List of all namespaces including brief documentation</a>
 *  - <a class="el" href="files.html">List of all files</a>
 *  - <a class="el" href="hierarchy.html">Class hierarchy</a>
 *  - <a class="el" href="classes.html">Alphabetical class index</a>
 *  - <a class="el" href="namespacemembers.html">Namespace members</a>
 *  - <a class="el" href="functions.html">Class members</a>
 *  - <a class="el" href="globals.html">File members</a>
 */



/**
 * \page PageInstallation Installation
 *
 * Follow this steps to create a local version of the ELL:
 *
 * - download and unzip the <A HREF="http://www.bioinf.uni-freiburg.de/SW/ELL/">ELL source package</A> distribution
 *
 * - run "./configure --help" to get an overview of further possible parameters
 * - run "./configure" with your desired parameters to generate the Makefiles
 * - "make" to generate the library
 *
 * - "make test" to test if everything works fine
 *
 * - "make doc" to generate the html documentation (if selected during the
 *   configure call)
 * - "make doxygen-doc" to generate the whole documentation
 *
 * See the file INSTALL in the library root path for further informations.
 *
 */

/**
 * \page PageTests Test cases and usage examples
 *
 * To check if the ELL does function as expected a test case was implemented
 * for each non-abstracted class.
 *
 * The source code can be used as an example for the usage of the ELL-classes.
 *
 * All files can be found in a subfolder named "tests" in the ELL root
 * directory. They are named in the format "testCLASSNAME.cc".
 *
 */