#ifndef RNAFREEENERGY_HH_
#define RNAFREEENERGY_HH_


#include "RNAStructure.hh"

namespace ell
{

		/**
		 * This subclass of RNAStructure implements the free energy as
		 * the underlying energy function.
		 * 
		 * @author Martin Mann, Sebastian Will, Andreas Richter
		 */
	class RNAFreeEnergy : public RNAStructure
	{
	public:
			/*! A single move (open or close one bond) on a RNA structure
		 	 *  at positions SingleMove.first and SingleMove.second.
		 	 */
		typedef std::pair<unsigned int, unsigned int> SingleMove;

		RNAFreeEnergy(	const std::string& rnaSeqStr,
			      		const Structure& _rnaStructBracketNot,
			     		const AllowedBasePairs* const _bPair);
			     		
		RNAFreeEnergy(const RNAFreeEnergy& rnaFreeEnerg);
		virtual ~RNAFreeEnergy();
		
			/*! Applies inplace a single move at the positions
			 *  given by move.
			 *  In case of invalid moves, the behaviour
			 *  of the program is not specified.
			 */
		void applySingleMove(const SingleMove& move);
		
			/*! Returns whether a move produces a valid RNA structure.
			 *  A move can only be valid if the first move position
			 *  move.first is less than the second move position
			 *  move.second!
			 */
		bool isValidSingleMove(const SingleMove& move) const;
		
			/*! Returns the next position for a closing bond
			 *  after pos which guarantes that the nested
			 *  property will be preserved.
			 * 
			 *  Returns RNAStructure::INVALID_INDEX if there is
			 *  no next valid position available.
			 */
		unsigned int nextCompatibleSingleMovePos(unsigned int pos) const;
		

	// abstract functions (BioMolecule)
		
			/*! Returns the free energy of this RNA structure. */
		virtual double	getEnergy() const;
	};

} // namespace ell

#endif /*RNAFREEENERGY_HH_*/
