#include <ell/AllowedBasePairs.hh>
#include <ell/assertell.hh>

namespace ell
{

	AllowedBasePairs::AllowedBasePairs(	const Alphabet* const _alph,
	 			const std::set< std::pair<std::string,std::string> >& bpSet)
		: alph(_alph) {
		// add the allowed base pairings to basePairSet
		for (std::set< std::pair<std::string,std::string> >::const_iterator
		     	it = bpSet.begin(); it != bpSet.end(); it++) {
			assertell(	(alph->isAlphabetString(it->first)
			 			&& alph->isAlphabetString(it->second)), 
			 			"The base pair "+it->first+", "+it->second
			 			+" is not part of the alphabet.");
			allowedBasePairSet.insert(BPair(	alph->getElement(it->first),
			 									alph->getElement(it->second)));
		}
	}

	AllowedBasePairs::~AllowedBasePairs() {
	}

	bool 
	AllowedBasePairs::operator== (const AllowedBasePairs& abp2) const {
		return *alph == *(abp2.alph)
			&& allowedBasePairSet == abp2.allowedBasePairSet;
	}

	bool 
	AllowedBasePairs::operator!= (const AllowedBasePairs& abp2) const {
		return *alph != *(abp2.alph)
			&& allowedBasePairSet != abp2.allowedBasePairSet;
	}

	bool 
	AllowedBasePairs::allowedBasePair(const Alphabet::AlphElem& first,
					const Alphabet::AlphElem& second) const {
		return (allowedBasePairSet.find(BPair(first, second))
				!= allowedBasePairSet.end()
				|| allowedBasePairSet.find(BPair(second, first))
				!= allowedBasePairSet.end() );
	}

}
