#include <ell/LatticeNeighborhood.hh>
#include <ell/assertell.hh>

namespace ell
{
	
	LatticeNeighborhood::LatticeNeighborhood(	const MoveAlphabet* moveAlph_, 
												const NeighSet& neighbors)
		:	moveAlph(moveAlph_), 
			neighSet(neighbors),	
			neighVec(moveAlph->getAlphabetSize(),NULL)
	{
		for (NeighSet::const_iterator it = neighSet.begin(); 
				it != neighSet.end(); it++){
			neighVec[moveAlph->getIndex(it->getMove())] = &(*it);
		}
		#ifndef NDEBUG	// pruefen ob alle moves in neighSet vertreten sind
			for (std::vector<NeighborVector*>::size_type i=0; 
					i< neighVec.size(); i++)
				assertell( neighVec[i] != NULL , 
"Incomplete initialisation of the neighbor vectors. Not all moves available.");
		#endif
	}
		
	LatticeNeighborhood::~LatticeNeighborhood()
	{
	}
	
	unsigned int 
	LatticeNeighborhood::size() const {
		return neighVec.size();
	}
	
	bool 
	LatticeNeighborhood::isElement( const IntPoint& vector) const {
		return neighSet.find(vector) != neighSet.end();
	}
	
	const NeighborVector& 
	LatticeNeighborhood::getElement(const IntPoint& vector) const {
		assertell(isElement(vector),
			"tried to get the neighbor vector of a non neighboring vector");
		return *(neighSet.find(vector));
	}
	
	const NeighborVector& 
	LatticeNeighborhood::getElement(const Move& move) const {
		return *(neighVec[moveAlph->getIndex(move)]);
	}		
	
	LatticeNeighborhood::const_iterator 
	LatticeNeighborhood::begin() const {
		return neighSet.begin();
	}

	LatticeNeighborhood::const_iterator 
	LatticeNeighborhood::end() const {
		return neighSet.end();
	}

} // namespace ell
