
#include <iostream>
#include <ell/RNAFreeEnergy.hh>


int main(int argc, char **argv) {

	using namespace ell;

	std::cout	<<"========== BEGIN OF TEST =================\n"
				<<" test class : RNAFreeEnergy\n"
				<<"==========================================" <<std::endl;
				
	std::cout	<<"=> create ell::Alphabet(ACGU,1) = alph" <<std::endl;
		ell::Alphabet* alph = new ell::Alphabet("ACGU", 1);
	std::cout	<<"=> create base pair set { AU, GU, CG } = bpSet" <<std::endl;
		std::set< std::pair<std::string,std::string> > bpSet;
		bpSet.insert(std::pair<std::string,std::string>("A","U"));
		bpSet.insert(std::pair<std::string,std::string>("G","U"));
		bpSet.insert(std::pair<std::string,std::string>("C","G"));
	std::cout	<<"=> create ell::AllowedBasePairs(alph, bpSet) = bp" 
				<<std::endl;
		ell::AllowedBasePairs* bp = new ell::AllowedBasePairs(alph, bpSet);
		std::string seqStr = "GGCAAAGUCAAAGAU";
	std::cout	<<"=> " <<seqStr <<" = seqStr" <<std::endl;
		std::string structStr = "..(...).(...)..";
	std::cout	<<"=> " <<structStr <<" = structStr" <<std::endl;
	std::cout	<<"=> create ell::RNAFreeEnergy(seqStr, structStr, bp)" 
				<<std::endl;
		ell::RNAFreeEnergy rnaStruct(seqStr, structStr, bp);

		// ==
	std::cout	<<"->(*this == *this)  = "
				<<(rnaStruct == rnaStruct ?"true":"false")
				<<std::endl;

		// !=
	std::cout	<<"->(*this != *this)  = "
				<<(rnaStruct == rnaStruct ?"true":"false")
				<<std::endl;

		// hasValidStructure()
	std::cout	<<"->hasValidStructure()  = "
				<<(rnaStruct.hasValidStructure() ? "true":"false")
				<<std::endl;

		// hasValidBasePairs()
	std::cout	<<"->hasValidBasePairs()  = "
				<<(rnaStruct.hasValidBasePairs() ? "true":"false")
				<<std::endl;

		// getMinLoopLength()
	std::cout	<<"->getMinLoopLength()  = "
				<<rnaStruct.getMinLoopLength()
				<<std::endl;

		// hasMinLoopLength()
	std::cout	<<"->hasMinLoopLength()  = "
				<<(rnaStruct.hasMinLoopLength() ? "true":"false")
				<<std::endl;

		// isAllowedBasePair() = false
	std::cout	<<"->isAllowedBasePair(0,4)  = "
				<<(rnaStruct.isAllowedBasePair(0,4) ? "true":"false")
				<<std::endl;

		// isAllowedBasePair() = false
	std::cout	<<"->isAllowedBasePair(INVALID_INDEX,4)  = "
				<<(rnaStruct.isAllowedBasePair(RNAStructure::INVALID_INDEX,4) ?
						"true":"false")
				<<std::endl;

		// isAllowedBasePair() = true
	std::cout	<<"->isAllowedBasePair(1,7)  = "
				<<(rnaStruct.isAllowedBasePair(1,7) ? "true":"false")
				<<std::endl;

		// getClosingBond(3)
	std::cout	<<"->getClosingBond(3)  = "
				<<rnaStruct.getClosingBond(3)
				<<std::endl;

		// getSequence()
	std::cout	<<"->alph.getString(rnaStruct.getSequence())  = "
				<<alph->getString(rnaStruct.getSequence())
				<<std::endl;
	std::cout	<<"->(alph.getString(rnaStruct.getSequence()) == seqStr)  = "
				<<(alph->getString(rnaStruct.getSequence()) == seqStr ? 
						"true":"false")
				<<std::endl;

		// getStructure()
	std::cout	<<"->getStructure()  = "
				<<rnaStruct.getStructure()
				<<std::endl;
	std::cout	<<"->((std::string)rnaStruct.getStructure() == structStr)  = "
				<<((std::string)rnaStruct.getStructure() == structStr ? 
						"true":"false")
				<<std::endl;

		// isValid()
	std::cout	<<"->isValid()  = "
				<<(rnaStruct.isValid() ? "true":"false")
				<<std::endl;

		// getStringRepresentation()
	std::cout	<<"->getStringRepresentation()  = "
				<<rnaStruct.getStringRepresentation()
				<<std::endl;

		// getEnergy()
	std::cout	<<"->getEnergy()  = "
				<<rnaStruct.getEnergy()
				<<std::endl;

	RNAFreeEnergy::SingleMove s15(1,5);
	std::cout	<<"=> creating SingleMove (" 
				<<s15.first <<","<<s15.second <<") = s15"
				<<std::endl;
	RNAFreeEnergy::SingleMove s17(1,7);
	std::cout	<<"=> creating SingleMove (" 
				<<s17.first <<","<<s17.second <<") = s17"
				<<std::endl;
				
		// isValidSingleMove() == false
	std::cout	<<"->isValidSingleMove(s15)  = "
				<<(rnaStruct.isValidSingleMove(s15) ?"true":"false")
				<<std::endl;

		// isValidSingleMove() == true
	std::cout	<<"->isValidSingleMove(s17)  = "
				<<(rnaStruct.isValidSingleMove(s17) ?"true":"false")
				<<std::endl;

		// getStructure()
	std::cout	<<"->getStructure()  = "
				<<rnaStruct.getStructure()
				<<std::endl;

		// applySingleMove()
	std::cout	<<"->applySingleMove(s17)" <<std::endl;
		rnaStruct.applySingleMove(s17);

		// getStructure()
	std::cout	<<"->getStructure()  = "
				<<rnaStruct.getStructure()
				<<std::endl;

		// nextCompatibleSingleMovePos(0)
	std::cout	<<"->nextCompatibleSingleMovePos(0)  = "
				<<rnaStruct.nextCompatibleSingleMovePos(0)
				<<std::endl;


	std::cout	<<"============= END OF TEST ================\n" <<std::endl;
	
	return 0;
}
